@@ -9,7 +9,7 @@ def safe(cmd, target):
         try:
             cmd(target, arg)
         except Exception as x:
-            print(x)
+            print(type(x).__name__, x)
     return do_cmd
 
 
@@ -29,7 +29,7 @@ class Repl(Cmd):
     def default(self, line):
         self.onecmd(f'run {line}')
 
-    def do_EOF(sef, arg):
+    def do_EOF(self, arg):
         return True
 
 
