@@ -20,6 +20,9 @@ from .manage import Manager
 from . import plugins
 
 
+# pylint: disable= filter-builtin-not-iterating
+
+
 class Target:
     def __init__(self, *,
         name = None,
@@ -246,7 +249,7 @@ class Target:
         if remove: self.run(f'rm {full}')
         return ret, out, err
 
-    def read(self, path, mode='rt'): todo(self)
+    def read(self, path, mode='rt', **kw): todo(self)
     def write(self, path, content, mode='rt'): todo(self)
     def send(self, local, remote): todo(self)
     def fetch(self, remote, local): todo(self)
