@@ -3,10 +3,13 @@ from os.path import isdir
 import sys
 
 from setux.core.target import Target
-from setux.logger import logger, debug, error, exception, info
+from setux.logger import logger, info
 from . import remote_tpl
 
 
+# pylint: disable=arguments-differ
+
+
 class SSH(Target):
     def __init__(self, **kw):
         self.host = kw.pop('host', None)
@@ -80,6 +83,7 @@ class SSH(Target):
             tmp.write(content)
             tmp.flush()
             self.send(tmp.name, path, quiet=True)
+        return self.read(path, mode=mode) == content
 
     def export(self, path):
         info(f'\texport -> {path}')
